package survey_result

import (
	"surveyService/response"
	"surveyService/service/survey_result"
	"surveyService/validators"

	"github.com/gin-gonic/gin"
)

// 获取详情
func DetailForManage(c *gin.Context) {
	type Validator struct {
		ID string `json:"id" form:"id" binding:"required"`
	}
	var validator Validator
	validateErr := c.ShouldBindQuery(&validator)
	if validateErr != nil {
		response.FailValidator(c, validateErr)
		return
	}

	surveyResult, err := survey_result.InitMechanism(nil).Detail(validator.ID)
	if err != nil {
		response.Fail(c, err)
		return
	}

	response.Success(c, map[string]any{
		"detail": survey_result.Format(surveyResult, true),
	})
}

// 获取列表
func PaginateForManage(c *gin.Context) {
	var validator validators.SurveyResultPaginate
	validateErr := c.ShouldBindQuery(&validator)
	if validateErr != nil {
		response.FailValidator(c, validateErr)
		return
	}

	surveyResultList, total, err := survey_result.InitMechanism(nil).Paginate(validator)
	if err != nil {
		response.Fail(c, err)
		return
	}

	var list = make([]*validators.SurveyResult, 0)
	for _, surveyResult := range surveyResultList {
		list = append(list, survey_result.Format(surveyResult, false))
	}

	response.Success(c, map[string]any{
		"list":  list,
		"total": total,
	})
}

// 重新执行一次
func RunForManage(c *gin.Context) {
	type Validator struct {
		ID string `json:"id" form:"id" binding:"required"`
	}
	var validator Validator
	validateErr := c.ShouldBind(&validator)
	if validateErr != nil {
		response.FailValidator(c, validateErr)
		return
	}

	err := survey_result.InitMechanism(nil).Run(validator.ID)
	if err != nil {
		response.Fail(c, err)
		return
	}

	response.Success(c, map[string]any{})
}
