package survey_disease

type TitleAndContent struct {
	Title   string `json:"title"`   //标题
	Content string `json:"content"` //内容
}

// 结果模板
type SurveyResultTemplate struct {
	Type             string            `json:"type"`             //模板类型 1:多行纯文本展示样式（Text） 2：多行标题与内容展示样式(TitleAndContents)
	Text             []string          `json:"text"`             //文本内容
	TitleAndContents []TitleAndContent `json:"titleAndContents"` //多标题与内容
}

// 输出结果
type SurveyResult struct {
	SurveyResultDatas []SurveyResultTemplate `json:"surveyResultData"` //结果数据
	AlTime            string                 `json:"alTime"`           //计算时间
}

type Item struct {
	Name          string   `json:"name"`          //项目名称
	Scope         string   `json:"scope"`         //适用范围 0-不限，1-男性，2-女性 3-女性未婚 4-女性已婚 5-备孕女性
	Radioactivity bool     `json:"radioactivity"` //是否放射性
	IsBasic       bool     `json:"isBasic"`       //是否基础项目
	IgnoreItem    []string `json:"ignoreItem"`    //忽略的项目
	IsAdd         bool     `json:"isAdd"`         //是否附加项目
	ChildrenItems []Item   `json:"childrenItems"` //子项目
}

var SysItemsForDiseaseScreening = []Item{
	{
		Name:          "一般检查",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{
			{
				Name:          "身高",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "体重",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "腰围",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "臀围",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "血压",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "脉搏",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
		},
	},
	{
		Name:          "内科检查",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "外科检查(含肛门指诊)",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "眼科检查",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{
			{
				Name:          "视力",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "眼压",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "眼底检查",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
		},
	},
	{
		Name:          "耳鼻喉科",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "口腔科",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "妇科检查",
		Scope:         "4",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "宫颈液基细胞学检查",
		Scope:         "4",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "HPV检查",
		Scope:         "4",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "血常规",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "尿常规",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "粪便常规",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "粪便隐血",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "粪便免疫化学测试",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       false,
		IgnoreItem:    []string{"粪便隐血"},
		ChildrenItems: []Item{},
	},
	{
		Name:          "血糖",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{
			{
				Name:          "空腹血糖",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "糖化血红蛋白",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
		},
	},
	{
		Name:          "血脂",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{
			{
				Name:          "总胆固醇",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "甘油三酯",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "高密度脂蛋白",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "低密度脂蛋白",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
		},
	},
	{
		Name:          "肝功能",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{
			{
				Name:          "白蛋白",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "丙氨酸氨基转移酶",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "天门冬氨酸氨基转移酶",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "总胆红素",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
		},
	},
	{
		Name:          "肾功能",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{
			{
				Name:          "血尿素氮",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "血肌酐",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "血尿酸",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
		},
	},
	{
		Name:          "甲状腺功能七项",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{
			{
				Name:          "三碘甲腺原氨酸",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "甲状腺素",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "游离三碘甲状腺原氨酸",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "游离甲状腺素",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "促甲状腺激素",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "甲状腺球蛋白抗体",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "甲状腺过氧化物酶抗体",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
		},
	},
	{
		Name:          "乙肝两对半",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{
			{
				Name:          "乙肝表面抗原",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "乙肝表面抗体",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "乙肝e抗原",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "乙肝e抗体",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "乙肝核心抗体",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
		},
	},
	{
		Name:          "乙肝病毒DNA定量",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       false,
		ChildrenItems: []Item{},
	},
	{
		Name:          "幽门螺杆菌检测",
		Scope:         "1",
		Radioactivity: true,
		IsBasic:       true,
		IgnoreItem:    []string{},
		ChildrenItems: []Item{
			{
				Name:          "C13呼气试验/C14呼气试验",
				Scope:         "1",
				Radioactivity: true,
				IsBasic:       true,
			},
		},
	},
	{
		Name:          "幽门螺杆菌检测",
		Scope:         "2",
		Radioactivity: true,
		IsBasic:       true,
		IgnoreItem:    []string{"幽门螺杆菌检查"},
		ChildrenItems: []Item{
			{
				Name:          "C13呼气试验/C14呼气试验",
				Scope:         "2",
				Radioactivity: true,
				IsBasic:       true,
			},
		},
	},
	{
		Name:          "幽门螺杆菌检查",
		Scope:         "2",
		Radioactivity: false,
		IsBasic:       true,
		IgnoreItem:    []string{},
		ChildrenItems: []Item{
			{
				Name:          "C13呼气试验",
				Scope:         "2",
				Radioactivity: false,
				IsBasic:       true,
			},
		},
	},

	{
		Name:          "胃功能",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       false,
		ChildrenItems: []Item{
			{
				Name:          "胃蛋白酶原I",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       false,
			},
			{
				Name:          "胃蛋白酶原II",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       false,
			},
			{
				Name:          "胃蛋白酶原比值",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       false,
			},
			{
				Name:          "胃泌素17",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       false,
			},
		},
	},

	{
		Name:          "肿瘤标志物",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{
			{
				Name:          "甲胎蛋白测定(AFP)定量",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "EB病毒衣壳抗原IgA抗体(VCA-IgA)",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "癌胚抗原测定(CEA)定量",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "神经元特异烯醇化酶测定(NSE)",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "细胞角蛋白19片段测定(CYFRA21-1)",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "糖链抗原50测定(CA50)",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "糖链抗原19-9测定(CA19-9)",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "糖链抗原242测定(CA242)",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "糖链抗原72-4测定(CA72-4)",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "特异生长因子测定(TSGF)",
				Scope:         "0",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "总前列腺特异性抗原测定(TPSA)",
				Scope:         "1",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "游离前列腺特异性抗原测定(FPSA)",
				Scope:         "1",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "糖链抗原125测定(CA125)",
				Scope:         "2",
				Radioactivity: false,
				IsBasic:       true,
			},
			{
				Name:          "糖链抗原15-3测定(CA15-3)",
				Scope:         "2",
				Radioactivity: false,
				IsBasic:       true,
			},
		},
	},
	{
		Name:          "肠癌基因检测",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       false,
		ChildrenItems: []Item{},
	},
	{
		Name:          "BRCA基因检测",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       false,
		ChildrenItems: []Item{},
	},
	{
		Name:          "十二导联心电图",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "心脏彩超",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "颈动脉彩超",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "甲状腺彩超",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "肝脏彩超",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "胆囊彩超",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "胰腺彩超",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "胰腺CT",
		Scope:         "0",
		Radioactivity: true,
		IsBasic:       false,
		IgnoreItem:    []string{"胰腺彩超"},
		ChildrenItems: []Item{},
	},
	{
		Name:          "胰腺MRI",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       false,
		IgnoreItem:    []string{"胰腺彩超"},
		ChildrenItems: []Item{},
	},
	{
		Name:          "胰腺CT/MRI",
		Scope:         "0",
		Radioactivity: true,
		IsBasic:       false,
		IgnoreItem:    []string{"胰腺CT", "胰腺MRI", "胰腺彩超"},
		ChildrenItems: []Item{},
	},
	{
		Name:          "脾脏彩超",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "肾脏彩超",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "膀胱彩超",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "输尿管彩超",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "前列腺彩超",
		Scope:         "1",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "乳腺彩超",
		Scope:         "2",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "妇科彩超(经腹)",
		Scope:         "3",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "妇科彩超(经阴道)",
		Scope:         "4",
		Radioactivity: false,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "乳腺X线(钼靶)",
		Scope:         "2",
		Radioactivity: true,
		IsBasic:       false,
		ChildrenItems: []Item{},
	},
	{
		Name:          "胸部低剂量螺旋CT",
		Scope:         "0",
		Radioactivity: true,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "骨密度",
		Scope:         "0",
		Radioactivity: true,
		IsBasic:       true,
		ChildrenItems: []Item{},
	},
	{
		Name:          "食管内镜",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       false,
		ChildrenItems: []Item{},
	},
	{
		Name:          "胃镜",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       false,
		IgnoreItem:    []string{"食管内镜"},
		ChildrenItems: []Item{},
	},
	{
		Name:          "肠镜",
		Scope:         "0",
		Radioactivity: false,
		IsBasic:       false,
		ChildrenItems: []Item{},
	},
}
