package algor

type BaseResponse[T any] struct {
	Code    int    `json:"code"`
	Data    T      `json:"data"`
	Message string `json:"message"`
	Success bool   `json:"success"`
}

type ListResponse[T any] struct {
	List []T `json:"list"`
}

type DetailResponse struct {
	Detail map[string]any `json:"detail"`
}

type AppAuth struct {
	ID              int64          `json:"id" form:"id"`
	AppId           int64          `json:"appId" form:"appId"`
	DecisionModelId int64          `json:"decisionModelId" form:"decisionModelId"`
	DecisionModel   *DecisionModel `json:"decisionModel" form:"decisionModel"`
	Remark          string         `json:"remark" form:"remark"`
	UsedTotal       int            `json:"usedTotal" form:"usedTotal"`
	Status          int            `json:"status" form:"status"`
	CreatedAt       string         `json:"createdAt"`
}
type DecisionModel struct {
	ID        int64  `json:"id" form:"id"`
	Name      string `json:"name" form:"name"`
	SN        string `json:"sn" form:"sn"`
	CreatedAt string `json:"createdAt" form:"-"`
}

type ExecuteRequest struct {
	Type            int            `json:"type" form:"type"`                       // 处理类型，1：问卷，2：ocr
	SurveyData      map[string]any `json:"surveyData" form:"surveyData"`           // 问卷数据
	OcrData         *OCRDataList   `json:"ocrData" form:"ocrData"`                 // ocr数据
	DecisionModelSN string         `json:"decisionModelSn" form:"decisionModelSn"` // 决策模型编号
	Extra           string         `json:"extra" form:"extra"`                     // 额外数据
}

type OCRDataList struct {
	UserName string           `json:"userName"` //用户姓名
	UserAge  int              `json:"userAge"`  //用户年龄
	UserSex  string           `json:"userSex"`  //用户性别
	OCRData  []map[string]any `json:"ocrData"`  //OCR数据
}

// 问题库
type QuestionnaireSubject struct {
	ID        int64  `json:"id" form:"id"`
	SN        string `json:"sn" form:"sn"`
	Type      int    `json:"type" form:"type"`
	Title     string `json:"title" form:"title"`
	Validator string `json:"validator" form:"validator"`
	Remark    string `json:"remark" form:"remark"`
	Mark      string `json:"mark" form:"mark"`
	CreatedAt string `json:"createdAt" form:"-"`
}

// 问题模板
type QuestionnaireTemplate struct {
	ID           int64  `json:"id" form:"id"`
	SN           string `json:"sn" form:"sn"`
	Title        string `json:"title" form:"title"`
	Peg          string `json:"peg" form:"peg"`
	SubjectTotal int64  `json:"subjectTotal" form:"-"` // 关联的题目数
	CreatedAt    string `json:"createdAt" form:"-"`
}
